| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Test.Tasty.AutoCollect.Config
Synopsis
- data AutoCollectConfig' f = AutoCollectConfig {
- cfgImports :: Apply f [FilePath]
- cfgSuiteName :: Apply f (Maybe Text)
- cfgGroupType :: Apply f AutoCollectGroupType
- cfgStripSuffix :: Apply f Text
- cfgIngredients :: Apply f [Text]
- cfgIngredientsOverride :: Apply f Bool
- cfgCustomMain :: Apply f Bool
- type AutoCollectConfig = AutoCollectConfig' Identity
- type AutoCollectConfigPartial = AutoCollectConfig' Maybe
- data AutoCollectGroupType
- parseConfig :: Text -> Either Text AutoCollectConfigPartial
- resolveConfig :: FilePath -> AutoCollectConfigPartial -> IO AutoCollectConfig
Documentation
data AutoCollectConfig' f Source #
Configuration for generating the Main module, specified as a block comment.
Constructors
| AutoCollectConfig | |
Fields
| |
Instances
data AutoCollectGroupType Source #
Constructors
| AutoCollectGroupFlat | All tests will be flattened like test1 test2 test3 |
| AutoCollectGroupModules | Tests will be grouped by module MyModule.MyTest1 test1 test2 MyModule.MyTest2 test3 |
| AutoCollectGroupTree | Test modules will be grouped as a tree MyModule
MyTest1
test1
test2
MyTest2
test3
|
Instances
| Show AutoCollectGroupType Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods showsPrec :: Int -> AutoCollectGroupType -> ShowS # show :: AutoCollectGroupType -> String # showList :: [AutoCollectGroupType] -> ShowS # | |
| Eq AutoCollectGroupType Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods (==) :: AutoCollectGroupType -> AutoCollectGroupType -> Bool # (/=) :: AutoCollectGroupType -> AutoCollectGroupType -> Bool # | |