| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Test.Tasty.AutoCollect.Config
Synopsis
Documentation
data AutoCollectConfig Source #
Configuration for generating the Main module, specified as a block comment.
Constructors
| AutoCollectConfig | |
Fields
| |
Instances
| Show AutoCollectConfig Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods showsPrec :: Int -> AutoCollectConfig -> ShowS # show :: AutoCollectConfig -> String # showList :: [AutoCollectConfig] -> ShowS # | |
| Eq AutoCollectConfig Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods (==) :: AutoCollectConfig -> AutoCollectConfig -> Bool # (/=) :: AutoCollectConfig -> AutoCollectConfig -> Bool # | |
data AutoCollectGroupType Source #
Constructors
| AutoCollectGroupFlat | All tests will be flattened like test1 test2 test3 |
| AutoCollectGroupModules | Tests will be grouped by module MyModule.MyTest1 test1 test2 MyModule.MyTest2 test3 |
| AutoCollectGroupTree | Test modules will be grouped as a tree MyModule
MyTest1
test1
test2
MyTest2
test3
|
Instances
| Show AutoCollectGroupType Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods showsPrec :: Int -> AutoCollectGroupType -> ShowS # show :: AutoCollectGroupType -> String # showList :: [AutoCollectGroupType] -> ShowS # | |
| Eq AutoCollectGroupType Source # | |
Defined in Test.Tasty.AutoCollect.Config Methods (==) :: AutoCollectGroupType -> AutoCollectGroupType -> Bool # (/=) :: AutoCollectGroupType -> AutoCollectGroupType -> Bool # | |